@@ -21,13 +21,9 @@ https://github.com/dz0ny/mopidy-beets/issues
 
 requests
 
-**Default config**
-
-.. code-block:: ini
-
 """
 
-__version__ = '1.0'
+__version__ = '1.0.1'
 
 
 class BeetsExtension(ext.Extension):
@@ -42,13 +38,10 @@ class BeetsExtension(ext.Extension):
 
     def get_config_schema(self):
         schema = super(BeetsExtension, self).get_config_schema()
-        schema['hostname'] = config.String()
+        schema['hostname'] = config.Hostname()
+        schema['port'] = config.Port()
         return schema
 
-    def validate_config(self, config):
-        if not config.getboolean('beets', 'enabled'):
-            return
-
     def validate_environment(self):
         try:
             import requests  # noqa
